#
# spec file for package axel
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?license: %global license %doc}
%{!?make_build: %global make_build make %{?_smp_mflags}}
Name:           axel
Version:        2.17.8
Release:        bp153.1.16
Summary:        Lightweight Download Accelerator
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/axel-download-accelerator/axel
Source:         https://github.com/axel-download-accelerator/axel/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)

%description
Axel tries to accelerate HTTP/FTP downloading process by using multiple
connections for one file. It can use multiple mirrors for a download. Axel has
no dependencies and is lightweight, so it might be useful as a wget clone on
byte-critical systems.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%find_lang axel

%files -f axel.lang
%doc ChangeLog NEWS README.md AUTHORS CREDITS
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun May 31 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.17.8:
  * CVE-2020-13614: SSL Certificate Hostnames were not verified
    (boo#1172159)
  * Replaced progressbar line clearing with terminal control sequence
  * Fixed parsing of Content-Disposition HTTP header
  * Fixed User-Agent HTTP header never being included
* Sun Mar 29 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.7:
  - Buildsystem fixes
  - Fixed release date for man-pages on BSD
  - Explicitly close TCP sockets on SSL connections too
  - Fixed HTTP basic auth header generation
  - Changed the default progress report to "alternate output mode"
  - Improved English in README.md
* Thu Oct 24 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.6:
  - Fixed handling of non-recoverable HTTP errors
  - Cleanup of connection setup code
  - Fixed manpage reproducibility issue
  - Use tracker instead of PTS from Debian
- update to version 2.17.5:
  - Fixed progress indicator misalignment
  - Cleaned up the wget-like progress output code
  - Improved progress output flushing
- update to version 2.17.4:
  - Fixed build with bionic libc (Android)
  - TCP Fast Open support on Linux
  - TCP code cleanup
  - Removed dependency on libm
  - Data types and format strings cleanup
  - String handling cleanup
  - Format string checking GCC attributes added
  - Buildsystem fixes and improvements
  - Updates to the documentation
  - Updated all translations
  - Fixed Footnotes in documentation
  - Fixed a typo in README.md
* Sun Jun  9 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.3:
  - Builds now use canonical host triplet instead of `uname -s`
  - Fixed build on Darwin / Mac OS X
  - Fixed download loops caused by last byte pointer being off by one
  - Fixed linking issues (i18n and posix threads)
  - Updated build instructions
  - Code cleanup
  - Added autoconf-archive to building instructions
- update to version 2.17.2:
  - Fixed HTTP request-ranges to be zero-based
  - Fixed typo "too may" -> "too many"
  - Replaced malloc + memset calls with calloc
  - Sanitize progress bar buffer len passed to memset
- update to version 2.17.1:
  - Fixed comparison error in axel_divide
  - Make sure maxconns is at least 1
- update to version 2.17:
  - Fixed composition of URLs in redirections
  - Fixed request range calculation
  - Updated all translations
  - Updated build documentation
  - Major code cleanup
  - Cleanup of alternate progress output
  - Removed global string buffers
  - Fixed min and max macros
  - Moved User-Agent header to conf->add_header
  - Use integers for speed ratio and delay calculation
  - Added support for parsing IPv6 literal hostname
  - Fixed filename extraction from URL
  - Fixed request-target message to proxy
  - Handle secure protocol's schema even with SSL disabled
  - Fixed Content-Disposition filename value decoding
  - Strip leading hyphens in extracted filenames
* Thu Mar 21 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- fix broken URL
* Sat Mar 10 2018 sebix+novell.com@sebix.at
- update to version 2.16.1:
  * no noteable changes
* Sun Nov 26 2017 aavindraa@gmail.com
- update to 2.16
  * Buildsystem fixes and improvements
  * Fixed bug that produces empty files with -q/--quiet
  * Fixed build with --disable-nls
  * Fixed formatting of the version/copyright message
  * Header files reorganization
  * Spanish translation
  * Style fixes
  * Updated Portuguese translation
* Sat Nov 11 2017 sebix+novell.com@sebix.at
- added more documentation files and license to package
* Sat Nov 11 2017 aavindraa@gmail.com
- update to 2.15 (see ChangeLog for release notes and all changes
  since 2.4)
- switch to new github url
- run spec-cleaner
- drop all patches
  * axel-fix_buffer_overflow.patch
    + upstreamed in 425dd156b76f2377a3e386324c282bdcdac90a40
  * axel-getaddrinfo.patch
    + upstreamed in cc1142b8de01e182cbaf4cc8a606c80696d8c0b8
  * axel-fix-url-max-length.patch
    + upstreamed in ce40ee76c25a84f386128927fcd0bab4e9751268
  * axel-2.4-configure.patch
    + unneeded
* Wed Apr 12 2017 sebix+novell.com@sebix.at
- run spec-cleaner
- add axel-fix-url-max-length.patch to accept longer URLs
* Thu Dec 22 2011 andreas.stieger@gmx.de
- Update License to GPL-2.0+
- add axel-2.4-configure.patch to make configure script accept and
  ignore --disable-dependency-tracking
* Tue Oct 12 2010 pascal.bleser@opensuse.org
- copied from home:bitshuffler to network:utilities
- revamped .spec file
- added patch to fix buffer overflow
- added patch to use getaddrinfo instead of gethostbyname
* Fri Jul  3 2009 bitshuffler #suse@irc.freenode.org
- Initial RPM
